@@ -403,7 +403,8 @@ class GeoUtilsTests(TestCase):
     def test_transform_geom(self):
         from swingers.tests.models import GeoDuck
         geo_duck = GeoDuck.objects.create(
-            poly="SRID=28349;POLYGON ((110 1200, 120 1210, 120 1220, 130 1222, 110 1200))")
+            poly="SRID=28349;POLYGON ((110 1200, 120 1210, 120 1220, 130 1222,"
+                 " 110 1200))")
         geom = transform_geom(geo_duck.poly)
         self.assertEqual(geom.coords,
                          (((499999.99999999994, 2035.0570603180677),
@@ -433,7 +434,8 @@ class GeoUtilsTests(TestCase):
         self.assertEqual(tl, u'586.70 KM N of \u0645\u0635\u0631 (Egypt)')
 
         geo_duck = GeoDuck.objects.create(
-            poly="POLYGON ((-10 -10, -10 10, 10 10, 10 -10, -10 -10))")
+            poly="POLYGON ((-10 100000, -10 100001, 10 100001, 10 100000,"
+                 " -10 100000))")
         tl = text_location(geo_duck.poly)
         self.assertEqual(tl, u'Nominatim Error: Unable to geocode')
 
